-- ----------------------------------------------------------------------- --

-- NOTE: This is the default schema for LibDB, and includes starter
-- relationships, locations, identifiers, and roles. This schema will
-- continue to be updated, providing "official" unique IDs to newly added
-- identifiers, roles, and relationships, faciliating sharing amongst
-- multiple installations.
--
-- A pretty-printed explanation of the database can be found at the
-- LibDB wiki: http://www.disobey.com/noos/LibDB/?DatabaseSchema.
--
--                                      -- Morbus Iff, morbus@disobey.com

-- ----------------------------------------------------------------------- --

-- libdb_drop_table_if_exists(table, cascade) instead of MySQL's DROP TABLE IF EXISTS...
-- for more information, see http://archives.postgresql.org/pgsql-novice/2003-03/msg00125.php
-- if you're a developer or of similar intent, uncomment the following to start fresh.
-- CREATE OR REPLACE FUNCTION libdb_drop_table_if_exists(text, bool) RETURNS bool AS 'DECLARE opt text; rec record; BEGIN IF $2 THEN opt := '' CASCADE''; ELSE opt := ''''; END IF; SELECT INTO rec oid FROM pg_class WHERE relname = $1::name; IF FOUND THEN EXECUTE ''DROP TABLE '' || $1 || opt; RETURN true; END IF; RETURN false; END; ' LANGUAGE 'plpgsql';
-- SELECT libdb_drop_table_if_exists( 'libdb_work',                true );
-- SELECT libdb_drop_table_if_exists( 'libdb_expression',          true );
-- SELECT libdb_drop_table_if_exists( 'libdb_manifestation',       true );
-- SELECT libdb_drop_table_if_exists( 'libdb_item',                true );
-- SELECT libdb_drop_table_if_exists( 'libdb_person',              true );
-- SELECT libdb_drop_table_if_exists( 'libdb_corporate_body',      true );
-- SELECT libdb_drop_table_if_exists( 'libdb_concept',             true );
-- SELECT libdb_drop_table_if_exists( 'libdb_object',              true );
-- SELECT libdb_drop_table_if_exists( 'libdb_place',               true );
-- SELECT libdb_drop_table_if_exists( 'libdb_event',               true );
-- SELECT libdb_drop_table_if_exists( 'libdb_annotations',         true );
-- SELECT libdb_drop_table_if_exists( 'libdb_annotations_types',   true );
-- SELECT libdb_drop_table_if_exists( 'libdb_characters',          true );
-- SELECT libdb_drop_table_if_exists( 'libdb_identifiers',         true );
-- SELECT libdb_drop_table_if_exists( 'libdb_identifiers_types',   true );
-- SELECT libdb_drop_table_if_exists( 'libdb_locations',           true );
-- SELECT libdb_drop_table_if_exists( 'libdb_locations_types',     true );
-- SELECT libdb_drop_table_if_exists( 'libdb_relationships',       true );
-- SELECT libdb_drop_table_if_exists( 'libdb_relationships_types', true );
-- SELECT libdb_drop_table_if_exists( 'libdb_roles',               true );
-- SELECT libdb_drop_table_if_exists( 'libdb_roles_types',         true );
-- SELECT libdb_drop_table_if_exists( 'libdb_variants',            true );

-- ----------------------------------------------------------------------- --

CREATE TABLE libdb_work                ( id CHAR(20) NOT NULL PRIMARY KEY, title TEXT NOT NULL, date DATE, distinctum TEXT, termination VARCHAR(50), audience TEXT, context TEXT );
CREATE TABLE libdb_expression          ( id CHAR(20) NOT NULL, work_id CHAR(20) NOT NULL, title TEXT NOT NULL, form VARCHAR(100), date DATE, language VARCHAR(5), distinctum TEXT, extensibility TEXT, revisability TEXT, audience TEXT, extent TEXT, context TEXT, restrictions TEXT, technique TEXT );
CREATE TABLE libdb_manifestation       ( id CHAR(20) NOT NULL, expression_id CHAR(20) NOT NULL, title TEXT NOT NULL, responsibility TEXT, date DATE, edition TEXT, series TEXT, carrier TEXT, extent TEXT, medium TEXT, capture TEXT, dimensions TEXT, availability TEXT, restrictions TEXT, color TEXT, presentation TEXT );
CREATE TABLE libdb_item                ( id CHAR(20) NOT NULL, manifestation_id CHAR(20) NOT NULL, provenance TEXT, marks TEXT, exhibition TEXT, condition TEXT, treatment TEXT, scheduled_treatment TEXT, access_restrictions TEXT );
CREATE TABLE libdb_person              ( id CHAR(20) NOT NULL PRIMARY KEY, name VARCHAR(255) NOT NULL, given_name VARCHAR(255), family_name VARCHAR(255), language VARCHAR(5), date_of_birth DATE, date_of_death DATE, title VARCHAR(50), designation VARCHAR(255) );
CREATE TABLE libdb_corporate_body      ( id CHAR(20) NOT NULL PRIMARY KEY, name VARCHAR(255) NOT NULL, date_of_birth DATE, date_of_death DATE, designation VARCHAR(255) );
CREATE TABLE libdb_concept             ( id CHAR(20) NOT NULL PRIMARY KEY, name VARCHAR(255) NOT NULL );
CREATE TABLE libdb_object              ( id CHAR(20) NOT NULL PRIMARY KEY, name VARCHAR(255) NOT NULL );
CREATE TABLE libdb_place               ( id CHAR(20) NOT NULL PRIMARY KEY, name VARCHAR(255) NOT NULL );
CREATE TABLE libdb_event               ( id CHAR(20) NOT NULL PRIMARY KEY, name VARCHAR(255) NOT NULL, start_date DATE, end_date DATE, frequency VARCHAR(255) );
INSERT INTO libdb_manifestation VALUES ( 'kjc87Kjagatw1Wesase4', '12k31jl89LK8712Klqpa', 'The Pool', 'Artisan Home Entertainment', '2003-02-18', 'American release version', NULL, 'DVD', '1 disc', NULL, NULL, NULL, 'Region 1 DVD (U.S. and Canada only); Not for sale to persons under age 18; Out of print;', NULL, 'color', 'widescreen');
INSERT INTO libdb_person VALUES        ( '666x666x666x666x666x', 'Kevin Hemenway', 'Kevin', 'Hemenway', 'en', NULL, NULL, NULL, NULL);
INSERT INTO libdb_concept VALUES       ( 'B1vuwBBZdfM0ww6ulasc', 'adult' );
INSERT INTO libdb_concept VALUES       ( 'HWD3GxoWlvkxcjoGash8', 'adventure' );
INSERT INTO libdb_concept VALUES       ( 'AWcvBcyXol9YKNPhtm0a', 'children' );
INSERT INTO libdb_concept VALUES       ( '5iaf5Si8WuzeqeqTDAas', 'comedy' );
INSERT INTO libdb_concept VALUES       ( 'z3W8Qk6MqvT2B81K1xse', 'cult' );
INSERT INTO libdb_concept VALUES       ( 'RRWFkLXRPQDdRTawDCTP', 'drama' );
INSERT INTO libdb_concept VALUES       ( 'si5N5k85GrzroGninE23', 'family' );
INSERT INTO libdb_concept VALUES       ( 'PlFy7UGVwPGaqo6jacFx', 'film noir' );
INSERT INTO libdb_concept VALUES       ( 'MYZLlQkPTdaMWT5DUkPv', 'gay and lesbian' );
INSERT INTO libdb_concept VALUES       ( 'n1hYzBdjwfjw1hH5egF2', 'horror' );
INSERT INTO libdb_concept VALUES       ( 'EpB2x6GaNAeM3rDIfNM6', 'murder' );
INSERT INTO libdb_concept VALUES       ( 'DW76LHQGG4CDAPm4qqwe', 'musical' );
INSERT INTO libdb_concept VALUES       ( '4vYvx7eUkqiGQsBou3fw', 'sci-fi' );
INSERT INTO libdb_concept VALUES       ( 'qhtqzKfnbabzDUw24p0a', 'war' );
INSERT INTO libdb_concept VALUES       ( '7ydW7loH0EbDrDTHEu4d', 'western' );
INSERT INTO libdb_event VALUES         ( 'jrEcxHgHZsXHwb0OTVMa', 'pool party', NULL, NULL, NULL );
INSERT INTO libdb_object VALUES        ( 'qa5idPbUUrHQGQvV1mrb', 'swimsuit' );
INSERT INTO libdb_object VALUES        ( 'utyzLgukZheVAYSulgfg', 'swimwear' );
INSERT INTO libdb_place VALUES         ( 'ZOQZOaTnbFDDIAGujgXu', 'pool' );
INSERT INTO libdb_place VALUES         ( 'bRMOVVf427M12VD9wTUw', 'Prague' );
INSERT INTO libdb_place VALUES         ( 'jr3w71KmqS0FTf1BNUKp', 'swimming pool' );
INSERT INTO libdb_place VALUES         ( 'KGD32LWuyZq31HQrEap3', 'waterslide' );
CREATE INDEX libdb_expression_idx    on libdb_expression (id,work_id);
CREATE INDEX libdb_manifestation_idx on libdb_manifestation (id,expression_id);
CREATE INDEX libdb_item_idx          on libdb_item (id,manifestation_id);

-- ----------------------------------------------------------------------- --

CREATE TABLE libdb_annotations             ( id CHAR(20) NOT NULL, referer_table VARCHAR(50) NOT NULL, referer_id CHAR(20) NOT NULL, annotation_type_id CHAR(20) NOT NULL, annotation TEXT NOT NULL, referent_table VARCHAR(50) NOT NULL, referent_id CHAR(20) NOT NULL );
CREATE TABLE libdb_annotations_types       ( id CHAR(20) NOT NULL PRIMARY KEY, name VARCHAR(100) NOT NULL, description TEXT NOT NULL );
INSERT INTO libdb_annotations_types VALUES ( 'MALzdLgFXQmc7Vjegzun', 'Chapters',         'The chapters could be from the contents page of a book or serial, or the technical chapters of a DVD manifestation.' );
INSERT INTO libdb_annotations_types VALUES ( '8UlKyTumJ95pC3nBwZOc', 'Review',           'A review or critique of the entity in question. The words here are the opinion of the referer, which rarely have any basis in reality.' );
INSERT INTO libdb_annotations_types VALUES ( '2QPxybTAMoEyjVupTa6k', 'Summarization',    'The summarization is an abstract or summary of the entity in question, often times from the back of the book, movie, etc.' );
INSERT INTO libdb_annotations_types VALUES ( 'mC1JAOXiwUkchWs2TaDI', 'Tagline',          'Many movies and books have a single sentence description on their cover referred to as a \"tagline\".' );

-- ----------------------------------------------------------------------- --

CREATE TABLE libdb_characters ( id CHAR(20) NOT NULL, referer_table VARCHAR(50) NOT NULL, referer_id CHAR(20) NOT NULL, persona TEXT NOT NULL, referent_table VARCHAR(50), referent_id CHAR(20) );

-- ----------------------------------------------------------------------- --

CREATE TABLE libdb_identifiers             ( id CHAR(20) NOT NULL, referer_table VARCHAR(50) NOT NULL, referer_id CHAR(20) NOT NULL, identifier_type_id CHAR(20) NOT NULL, identifier TEXT );
CREATE TABLE libdb_identifiers_types       ( id CHAR(20) NOT NULL PRIMARY KEY, name VARCHAR(100) NOT NULL, description TEXT NOT NULL );
INSERT INTO libdb_identifiers_types VALUES ( 'CVxByT1K0a2lcfMVi0j4', 'ASIN',         'ASIN stands for Amazon Standard Identification Number. Almost every product on our site has its own ASIN -- a unique code we use to identify it. For books, the ASIN is the same as the ISBN number, but for all other products a new ASIN is created when the item is uploaded to our catalogue.' );
INSERT INTO libdb_identifiers_types VALUES ( '1H7tVsmrA1mbrxQWTKfA', 'DOI',          'DOIs are names \(characters and/or digits\) assigned to objects of intellectual property \(physical, digital or abstract\) such as electronic journal articles, images, learning objects, ebooks, images, any kind of content. They are used to provide current information, including where they \(or information about them\) can be found on the Internet. Information about a digital object may change over time, including where to find it, but its DOI will not change.' );
INSERT INTO libdb_identifiers_types VALUES ( 'LsDwzmSpSTXf5poXzSIh', 'Fingerprint',  'A fingerprint is an identifier constructed by combining groups of characters transcribed from specified pages of a printed item.  The technique is used primarily to signal differences between individual copies of early printed books.' );
INSERT INTO libdb_identifiers_types VALUES ( 'lJT0NNFWvPNUHPFU35PA', 'IMDb',         'The Internet Movie Database uses a nine-digit string to identify its resources; the first two characters determine whether it\'s a movie title or person\'s name.' );
INSERT INTO libdb_identifiers_types VALUES ( 's7dzo7xsxeAN4WD9Jh1y', 'ISSN',         'The ISSN \(International Standard Serial Number\) is an eight-digit number which identifies periodical publications as such, including electronic serials. More than one million ISSN numbers have so far been assigned.' );
INSERT INTO libdb_identifiers_types VALUES ( 'xhC5cUEseR208u4jkKGV', 'ISBN',         'The ISBN is a unique machine-readable identification number, which marks any book unmistakably. For 30 years the ISBN has revolutionized the international book-trade. 159 countries and territories are officially ISBN members.' );
INSERT INTO libdb_identifiers_types VALUES ( 'crKg5OznuFZ1A6U6kS28', 'LCCN',         'The Library of Congress began to print catalog cards in 1898 and began to distribute them in 1901. The Library of Congress Card Number was the number used to identify and control catalog cards.' );
INSERT INTO libdb_identifiers_types VALUES ( 'ks8iH6UoVugsgc9btI9c', 'UPC Type A',   'The basic UPC code, referred to as Type A, is composed of twelve digits. These twelve digits are broken up into four groups: Number System Character, Manufacturer\'s Code, Product Code, and Check Digit.' );
INSERT INTO libdb_identifiers_types VALUES ( 'ZhBU2tsUYphad23MTl9a', 'UPC Type E',   'All Type-E UPC codes are eight digits long, the first being the Number System Character and the last being the check digit. The number system character is ALWAYS ZERO. The check digit is calculated from the digits in the Type-A UPC.' );

-- ----------------------------------------------------------------------- --

CREATE TABLE libdb_locations             ( id CHAR(20) NOT NULL, item_id CHAR(20) NOT NULL, location_type_id CHAR(20) NOT NULL );
CREATE TABLE libdb_locations_types       ( id CHAR(20) NOT NULL PRIMARY KEY, name VARCHAR(100) NOT NULL, description TEXT );
INSERT INTO libdb_locations_types VALUES ( 'wIINYBlgzIEe4RukLR6G', 'DVD Shelf 1', 'All DVDs on this shelf are organized alphabetically, and are spine up.' );
INSERT INTO libdb_locations_types VALUES ( 'tx8D0PodmXdY0IjGx5PI', 'VHS Shelf 1', 'All VHS tapes on this shelf are organized alphabetically, and are spine up. Oversized items are organized according to their size (in other words, there is neither rhyme nor reason to their placement).' );

-- ----------------------------------------------------------------------- --

CREATE TABLE libdb_relationships             ( id CHAR(20) NOT NULL, referer_table VARCHAR(50) NOT NULL, referer_id CHAR(20) NOT NULL, relationship_type_id CHAR(20) NOT NULL, referent_table VARCHAR(50) NOT NULL, referent_id CHAR(20) NOT NULL );
CREATE TABLE libdb_relationships_types       ( id CHAR(20) NOT NULL PRIMARY KEY, name VARCHAR(100) NOT NULL, subject VARCHAR(100) NOT NULL, object VARCHAR(100) NOT NULL, description TEXT NOT NULL );
INSERT INTO libdb_relationships_types VALUES ( 'EPFxZ1WjoTD2xCT9dm2c', 'Work <=> Work',      'is related to',   'is related to', 'This defines a relationship \(of an indeterminate nature\) between two works.' );
INSERT INTO libdb_relationships_types VALUES ( 'maQE6fKhSdeIejeVuB1h', 'Concept <=> Entity', 'is a concept of', 'has concept',   'This relationships defines the connection between a concept and another entity. ');
INSERT INTO libdb_relationships_types VALUES ( 'RmRHNJZVJgGvYzjDm3a1', 'Object <=> Entity',  'is an object of', 'has object',    'This relationships defines the connection between an object and another entity. ');
INSERT INTO libdb_relationships_types VALUES ( 'P25g2NMfd9lmNpU876gr', 'Place <=> Entity',   'is a place of',   'has place',     'This relationships defines the connection between a place and another entity. ');
INSERT INTO libdb_relationships_types VALUES ( 'A1Bt2vIYQbd7aOdakHGC', 'Event <=> Entity',   'is an event of',  'has event',     'This relationships defines the connection between an event and another entity. ');
CREATE INDEX libdb_relationships_idx on libdb_relationships (referer_id,referent_id);

-- ----------------------------------------------------------------------- --

CREATE TABLE libdb_roles             ( id CHAR(20) NOT NULL, referer_table VARCHAR(50) NOT NULL, referer_id CHAR(20) NOT NULL, role_type_id CHAR(20) NOT NULL, referent_table VARCHAR(50) NOT NULL, referent_id CHAR(20) NOT NULL );
CREATE TABLE libdb_roles_types       ( id CHAR(20) NOT NULL PRIMARY KEY, name VARCHAR(100) NOT NULL, description TEXT);
INSERT INTO libdb_roles_types VALUES ( 'VqRnCazkiLfuXC8BYxul', '2D Artist',                      'The 2D Artist is responsible for putting together various elements into one finished product or doing frame-by-frame touch up work \(known as rotoscoping\). This process is used in cases where wires or rigging may need to be removed or where defects have occurred in the filming process, such as negative scratches, hairs in the camera gate, or dirt present in various developing processes. In addition to the alteration and rectification of these types of anomalies of the film process, 2D artists may also do some work with editing and color grading. \(Source: Animal Logic\)' );
INSERT INTO libdb_roles_types VALUES ( 'aCnvaEsAdTQg3wg1Lbu4', 'ADR & Dubbing Recording',        'Automatic dialog replacement, also "post sync" or "looping", is when actors re-record their lines in a controlled environment while watching themselves onscreen. \(Source: LibDB\)' );
INSERT INTO libdb_roles_types VALUES ( 'hN4rdi4xKWcmjPx284V3', 'Art Director',                   'The person who oversees the artists and craftspeople who build the sets. See also production designer, set designer, set director. \(Source: IMDb\)' );
INSERT INTO libdb_roles_types VALUES ( 'Oe2hAUUC0LFeKIn4s0iR', 'Assistant Art Director',         'An assistant to the art director. \(Source: IMDb\)' );
INSERT INTO libdb_roles_types VALUES ( 'OO2j0IPlZRdITC9u2Q35', 'Assistant Camera',               'A member of the camera crew who assists the camera operator. This person is reponsible for the maintenance and care of the camera, as well as preparing dope sheets. In smaller camera crews, they may also perform the duties of clapper-loader and/or a focus puller. \(Source: IMDb\)' );
INSERT INTO libdb_roles_types VALUES ( 'm5SYzC2AH1vByOII29OC', 'Assistant Director',             'An assistant director\'s duties include tracking the progress of filming versus the production schedule, and preparing call sheets. \(Source: IMDb\)' );
INSERT INTO libdb_roles_types VALUES ( 'WjLZXn24dQS5ToVl1IiS', 'Assistant Film Editor',          'Editing room crewmember responsible for providing any and all required logistical assistance to the editor\(s\). Duties vary, depending on whether the assistant is working with a picture or sound editor and whether the show is being edited on film or on a non-linear editing system. On a film-edited show, assistant picture editors will, during production: liase with the film lab and sound transfer facility regarding the processing of dailies; leader, sync and edgecode the dailies rolls; coordinate and take notes during dailies screenings; organize and maintain camera reports, sound reports, script notes, and lined script pages from the set, as well as lab reports and sound transfer reports; log all dailies footage; and reorganize footage for editing, if necessary. Ongoing, and during post-production, they will: reconstitute trims; locate and pull trims requested by the editor; check sync, clean, measure, re-splice, and add change-over marks to cut reels; coordinate screenings of cut work; take notes during screenings. Once the sound department begins work, the assistants produce change sheets detailing each day\'s changes to the workprint and production track and send them, along with any necessary duplicate trims, to the sound department. Assistants may be permitted by the editor to do some creative work, such as commenting on the editor\'s work; cutting temporary sound effects and music into the track; and sometimes even editing scenes. After picture lock, the assistant: oversees the creation of optical effects such as fades, dissolves, etc. and cuts them into the workprint; continues to work with the sound department as necessary; and in some cases oversees the final stages of post-production, all the way through sound mix, negative conforming, and the production of final prints. The assistant editor chain of command consists of the First Assistant Editor(s), who bears the most responsibility for the smooth performance of the assistant team; the Second Assistant Editor\(s\); and the Apprentice Editor\(s\) \(Source: IMDb\).' );
INSERT INTO libdb_roles_types VALUES ( 'jl3WDDbSD3zvfXJNrkMT', 'Assistant Hair Stylist',         'The decorations placed directly on the skin or hair of an actor for cosmetic or artistic effect. Practitioners are called artists or supervisors. \(Source: IMDb\)' );
INSERT INTO libdb_roles_types VALUES ( 'eCtOUe9YhSIqIIqqGIPP', 'Assistant Makeup Artist',        'The decorations placed directly on the skin or hair of an actor for cosmetic or artistic effect. Practitioners are called artists or supervisors. \(Source: IMDb\)' );
INSERT INTO libdb_roles_types VALUES ( 'zyrsgVdDBmwEYNVoSZGM', 'Assistant Underwater Camera',    'A member of the camera crew who assists the underwater camera operator. \(Source: IMDb, LibDB\)' );
INSERT INTO libdb_roles_types VALUES ( 'ks8iH6UoVugsgc9btI9c', 'Associate Producer',             'An individual who performs a limited number of producing functions delegated to her/him by a producer, under the direct supervision and control of that producer. The term may also refer to a person who would qualify as an executive producer of a project, but for the fact that \(s\)he acts on behalf of a production company which is subordinate to another one on that project. See also co-producer and line producer. \(Source: IMDb\)' );
INSERT INTO libdb_roles_types VALUES ( 'v3wQ2mNq2jJGKvCREwBH', 'Best Boy',                       'The chief assistant, usually of the gaffer, but more often lately used as a general term for the second in command of a group. This term is likely borrowed from early sailing and whaling crews, as sailors were often employed to set up and work rigging in theatres. There are no "best girls" per se; female chief assistants are also called "Best Boys" \(Source: IMDb\).' );
INSERT INTO libdb_roles_types VALUES ( '0uGD6jUDxmBgc0cK6n9Z', 'Boom Operator',                  'A member of the sound crew who operates the boom microphone. \(Source: IMDb\)' );
INSERT INTO libdb_roles_types VALUES ( 'eIimqQe9PZLrmqoDbeNi', 'Camera Operator',                'The person who operates the camera to the specifications dictated by the director of photography. A director or a director of photography sometimes assumes this role. \(Source: IMDb\)' );
INSERT INTO libdb_roles_types VALUES ( 'Iqs4WxIXhhoaAuAAaLkM', 'Camera Equipment',               'A person or company that has provided camera tools equipement for use in filming, including dollies, jibs, stands, etc. \(Source: LibDB\)' );
INSERT INTO libdb_roles_types VALUES ( 'pI1Iltd2PEbATWKS6toG', 'Cast Member',                    'A generic term for the actors, actresses, leads, supporting roles, etc. that make up the performance of a particular film or movie. \(Source: LibDB\)' );
INSERT INTO libdb_roles_types VALUES ( 'NaHtHFjQNNrqqZUSCK7K', 'Casting',                        'The process of hiring actors to play the characters in a script, typically done by a casting director, but with some input from a director, producer, or studio. \(Source: IMDb\)' );
INSERT INTO libdb_roles_types VALUES ( 'CXwQ9OgCWXNlWIlnGjWF', 'Cinematographer',                'A person with expertise in the art of capturing images either electronically or on film stock through the application of visual recording devices and the selection and arrangement of lighting. The chief cinematographer for a movie is called the director of photography. \(Source: IMDb\)' );
INSERT INTO libdb_roles_types VALUES ( '2tTKl196aWbZKhVJVc8O', 'Clapper Loader',                 'The person who operates the clapboard at the beginning of a shot, also responsible for loading film stock into film magazines. The action of slapping the clapper was invented as a way of synchronizing the visual and audio components of a shot. Recent innovations in audio-visual synchronization have made this unnecessary, but it still occurs extensively. \(Source: IMDb\)' );
INSERT INTO libdb_roles_types VALUES ( 'ZhBU2tsUYphad23MTl9a', 'Co-Producer',                    'A producer who performs a substantial portion of a creative producing function, or who is primarily responsible for one or more managerial producing functions. A co-producer has less responsibility than a producer for the completion of a project. Note that if a project has more than one producer, it doesn\'t mean that these individuals are "co-producers" in the technical sense of that term. See also executive producer, associate producer, line producer. \(Source: IMDb\)' );
INSERT INTO libdb_roles_types VALUES ( 'AtYNxDbeBBTSQnfbjSRX', 'Color Timing',                   'A process which adjusts the final print so that colors match from shot to shot, regardless of the film stock and camera used to shoot the scene. So named because one aspect is adjusting the exposure time of each shot. Performed by a color timer. \(Source: IMDb\)' );
INSERT INTO libdb_roles_types VALUES ( 'wlcSMWmjFyEUDW8ly2va', 'Composer',                       'A musician whose music appears in a movie\'s score. Most movies have at least some original music written for the score, usually after the relevant parts of the movie have been filmed. \(Source: IMDb\)' );
INSERT INTO libdb_roles_types VALUES ( 'SWn40qVebAC3WNKCxvUY', 'Conductor',                      'A person who directs the orchestra\'s performance of the score, often the composer. \(Source: IMDb\)' );
INSERT INTO libdb_roles_types VALUES ( '9SJuzxJs9lMws02ZnMBf', 'Costume Designer',               'A person who designs the costumes for a movie. \(Source: IMDb\)' );
INSERT INTO libdb_roles_types VALUES ( 'j8nAmBBtpb4r26CjWggZ', 'Dialogue Editor',                'A sound editor who specializes in editing dialogue. \(Source: IMDb\)' );
INSERT INTO libdb_roles_types VALUES ( '7GVu9WfxUfXRMy2jijAL', 'Digital Film Scanning',          'The person or company responsible for converting the raw film taken during a shoot into a computerized format, which can then be used to remove blemishes and other film artifacting, or for the addition or enchancement of visual and special effect enhancement. \(Source: LibDB\)' );
INSERT INTO libdb_roles_types VALUES ( 'UwNifmwPUdELnC8LcP6q', 'Director',                       'The principal creative artist on a movie set. A director is usually \(but not always\) the driving artistic source behind the filming process, and communicates to actors the way that he/she would like a particular scene played. A director\'s duties might also include casting, script editing, shot selection, shot composition, and editing. Typically, a director has complete artistic control over all aspects of the movie, but it is not uncommon for the director to be bound by agreements with either a producer or a studio. In some large productions, a director will delegate less important scenes to a second unit. \(Source: IMDb\)' );
INSERT INTO libdb_roles_types VALUES ( 'JVcz1T74DldqBuso7KSL', 'Director Of Photography',        'A cinematographer who is ultimately responsible for the process of recording a scene in the manner desired by the director. The Director of Photography has a number of possible duties: selection of film stock, cameras, and lenses; designing and selecting lighting, directing the gaffer\'s placement of lighting; shot composition \(in consultation with the director\); film developing and film printing.' );
INSERT INTO libdb_roles_types VALUES ( 'RnYUXEkxlJc2VjLHWSrd', 'Distributor',                    'The organization responsible for coordinating the distribution of the finished movie to exhibitors, as well as the sale of videos, laserdiscs, and other media versions of movies. \(Source: IMDb\)' );
INSERT INTO libdb_roles_types VALUES ( 'WiiQZ5P7t3Tx1mhkw33V', 'Editor',                         'A person who performs editing \(in consultation with the director\) on a movie. This term usually refers to someone who does visual editing. \(Source: IMDb\)' );
INSERT INTO libdb_roles_types VALUES ( 'C0oIkYDlUdBVYZ9Bh5UP', 'Executive Producer',             'A producer who is not involved in any technical aspects of the filmmaking process, but who is still responsible for the overall production. Typically an executive producer handles business and legal issues. See also associate producer, co-producer, line producer. \(Source: IMDb\)' );
INSERT INTO libdb_roles_types VALUES ( 'K4PTD8o9p1yJAg4ZP34U', 'First Assistant Camera',         'A member of the camera crew who adjusts the focus of the camera during filming. \(Source: IMDb\)' );
INSERT INTO libdb_roles_types VALUES ( 'xwpoLyjF3OxMejndZTIP', 'Foley Artist',                   'A person who creates foley sound effects. Named after an early practitioner. \(Source: IMDb\)' );
INSERT INTO libdb_roles_types VALUES ( 'A55Xs1hB4SA5eWHcv2V6', 'Foley Editor',                   'Edits the sounds created by a foley artist. \(Source: IMDb\)' );
INSERT INTO libdb_roles_types VALUES ( 'csqp3YbMresCsWNJTKTP', 'Funding',                        'The funding corporate body or person helps finance the film\'s creation, covering expenses for equipment, promotion, etc. \(Source: LibDB\)' );
INSERT INTO libdb_roles_types VALUES ( 'yxLgjzU8CHgs3A0mIWgr', 'Gaffer',                         'The head of the electrical department, responsible for the design and execution of the lighting plan for a production. Early films used mostly natural light, which stagehands controlled with large tent cloths using long poles called gaffs \(stagehands were often beached sailors or longshoremen, and a gaff is a type of boom on a sailing ship\). In 16th Century English, the term "gaffer" denoted a man who was the head of any organized group of laborers. \(Source: IMDb\)' );
INSERT INTO libdb_roles_types VALUES ( 'EVQ5d7vM1BNyk2SPTvYb', 'Grip',                           'In the USA, a grip is a person responsible for the adjustment and maintenance of production equipment on the set. Their typical duties include laying dolly tracks or erecting scaffolding. In the UK, grips work exclusively with equipment that the camera is mounted on. Contrast with swing gang, see also key grip. \(Source: IMDb\)' );
INSERT INTO libdb_roles_types VALUES ( 'Xi9uErmZvyNNh0Vr3XCu', 'Key Grip',                       'The chief of a group of grips, often doubling for a construction co-ordinator and a backup for the camera crew. Key grips work closely with the gaffer. \(Source: IMDb\)' );
INSERT INTO libdb_roles_types VALUES ( 'H3FtibZbZa5IVVTXSdi2', 'Key Hair Stylist',               'The decorations placed directly on the skin or hair of an actor for cosmetic or artistic effect. Practitioners are called artists or supervisors. \(Source: IMDb\)' );
INSERT INTO libdb_roles_types VALUES ( 'BIMrbfhMdhhtq26SV6M7', 'Key Makeup Artist',              'The decorations placed directly on the skin or hair of an actor for cosmetic or artistic effect. Practitioners are called artists or supervisors. \(Source: IMDb\)' );
INSERT INTO libdb_roles_types VALUES ( 'lg2yq2xiUbmlMBf4Ok0d', 'Lighting Technician',            'Members of the production crew who set up and operate electrical lighting equipment. \(Source: California Employment Development Department\)' );
INSERT INTO libdb_roles_types VALUES ( 'klokpHk6ONiD1rQeS6A8', 'Line Producer',                  'A producer who is responsible for managing every person and issue during the making of a film. Line producers only work on one film at a time. See also: unit production manager, associate producer, co-producer, executive producer. \(Source: IMDb\)' );
INSERT INTO libdb_roles_types VALUES ( 'N5WpGRNDIC4TvcyhJZq6', 'Location Manager',               'A person who manages various aspects of filming on location, such as arranging with authorities for permission to shoot in specific places. \(Source: IMDb\)' );
INSERT INTO libdb_roles_types VALUES ( '7m2fdPNaJTIcSDV9f96Y', 'Music Coordinator',              'A music coordinator works with the composer or songwriter to establish an accurate and realistic budget, and manage the music creation and recording processes to make sure the budget is maintained and followed. Music coordinators can also work with contractors to make sure the appropriate number and type of musicians are hired, and can assist with musicians\' union contracts and arrangements. Music coordinators can also be helpful in recommending payroll services, and making good matches between composers and orchestrators, arrangers, scoring mixers, and other parts of the music production team. \(Source: Film Music Magazine\)' );
INSERT INTO libdb_roles_types VALUES ( '4sOLVFlsxTR2eRNPPf3M', 'Negative Cutter',                'A person who matches the negative of a movie and conforms (matches) it to the final version of the film as decided by the filmmakers. From this negative the prints are made. \(Source: IMDb\)' );
INSERT INTO libdb_roles_types VALUES ( '0EIouat8c51xfdHA02WT', 'Orchestra Contractor',           'It is the contractor\'s job to hire the musicians, handle the payroll, and see to it that everyone abides by the union work rules. \(Source: John Hopkin\'s Magazine\)' );
INSERT INTO libdb_roles_types VALUES ( 'FtOps5DYBAXvBuU5wXZF', 'Orchestrator',                   'A person who writes orchestral arrangements. \(Source: IMDb\)' );
INSERT INTO libdb_roles_types VALUES ( 'BTiMtVZjEo5fJW4MTAKY', 'Owner',                          'A person or corporate body that owns, or is a custodian of, a specific item. \(Source: LibDB\)' );
INSERT INTO libdb_roles_types VALUES ( '3y6l6hhw2Dkj5hGASknz', 'Post-Production Accountant',     'Responsible for the coordination, supervision, and operation of the accounting department after principle phootgraphy has been completed. \(Source: Director\'s Guild of Canada\)' );
INSERT INTO libdb_roles_types VALUES ( 'BSW9r1FDrePQvLTbslJs', 'Post-Production Supervisor',     'A person overseeing the entire post-production of a project. They report directly to the producer and/or the studio in charge of the feature. Working side by side with the director and editor, the supervisor has the responsibility of finishing the film on time and on budget while satisfying the wants of the director. Post-production supervisors have authority over post-production co-ordinators. Typical duties include: Controlling all activities with vendors such as optical houses, sound facilities, inserts, ADR, reshooting, CGI, score, delivery requirements to domestic and international distributors, legal clearances, preview screenings, color timing, video mastering and budgeting the movie through the completion and delivery. \(Source: IMDb\)' );
INSERT INTO libdb_roles_types VALUES ( 'KX2gUujh3dsBJvLEkMMR', 'Producer',                       'The chief of a movie production in all matters save the creative efforts of the director. A producer is responsible for raising funding, hiring key personnel, and arranging for distributors. See also associate producer, co-producer, executive producer, line producer. \(Source: IMDb\)' );
INSERT INTO libdb_roles_types VALUES ( 'zolzYaYS2VTF4OFmzpiG', 'Production Accountant',          'The person responsible for managing finances during the production. \(Source: IMDb\)' );
INSERT INTO libdb_roles_types VALUES ( 'ryTwf75OWzqKnpL15PTM', 'Production Assistant',           'A person responsible for various odd jobs, such as stopping traffic, acting as couriers, fetching items from craft service, etc. Production Assistants are often attached to individual actors or filmmakers. \(Source: IMDb\)' );
INSERT INTO libdb_roles_types VALUES ( 'nS8x6Sms64Hbl5jst0yi', 'Production Company',             'A general term for a company that is associated with the making of a movie. \(Source: IMDb\)' );
INSERT INTO libdb_roles_types VALUES ( '4Xtu5WmMOfLXUAeOcpfe', 'Production Coordinator',         'The person responsible for overseeing practical matters such as ordering equipment, getting near-location accommodations for the cast and crew, etc. \(Source: IMDb\)' );
INSERT INTO libdb_roles_types VALUES ( 'YRjINuwAQyYq6ec4genf', 'Production Designer',            'An artist responsible for designing the overall visual appearance of a movie. \(Source: IMDb\)' );
INSERT INTO libdb_roles_types VALUES ( 'U1FTHiUiuWHdjka5WlCW', 'Production Sound Mixer',         'The head of the sound department on the set. They are responsible for the process of recording all sync dialog and sync sound effects in a scene. The Production Sound Mixer has a number of duties: selection and operation of the microphones, and recording equipment used on the set, directing the boom operator, combining the sound of multiple microphones used to capture dialog and effects on a set, recording sound ambiance and room tone for all scenes, and wild track that will aid the editor and sound mixer in matching the different sound takes in a scene for smooth sound transitions. \(Source: IMDb\)' );
INSERT INTO libdb_roles_types VALUES ( 'u7GfrspQnBSywt2PetFP', 'Property Master',                'The person responsible for buying, acquiring, and/or manufacturing any props needed for a production. The property master is responsible for all aspects of prop use on the set and, in conjunction with the script supervisor, for maintaining set continuity. \(Source: IMDb\)' );
INSERT INTO libdb_roles_types VALUES ( 'P3825rcM0vGO2e9jAnOu', 'Second Assistant Director',      'An assistant to the assistant director. Duties include overseeing the movements of the cast, and preparing call sheets. \(Source: IMDb\)' );
INSERT INTO libdb_roles_types VALUES ( 'S6VBJKBuuX3Q2T8Qp8Bk', 'Score Engineer',                 'Also known as a scoring mixer, a score engineer records and mixes the music during recording sessions, working closely with composers and songwriters to ensure the process happens successfully. \(Source: Film Music Magazine\)' );
INSERT INTO libdb_roles_types VALUES ( 'Hmo0VxsyKUL1SW2GMlKC', 'Score Recordist',                'A score recordist runs video playback, analog and digital tape machines, handles synchronization, patching, console automation, virtual timecode, surround mix bussing, and stereo "fold down" versions of the surround mixes. \(Source: TapeOp.com\)' );
INSERT INTO libdb_roles_types VALUES ( 'XP8isbDXKdeBX7kITU2W', 'Screenwriter',                   'A writer who either adapts an existing work for production as a movie, or creates a new screenplay. \(Source: IMDb\)' );
INSERT INTO libdb_roles_types VALUES ( 'THm5vTRObkRGrQkb1I4X', 'Script Editor',                  'A process whereby a script is reviewed and changed, based on input from various sources such as the director or producer. Writers who specialize in script editing are called "script doctors", and are frequently uncredited. \(Source: IMDb\)' );
INSERT INTO libdb_roles_types VALUES ( 'zKUJqi9FQHGwZiKr7q67', 'Script Supervisor',              'A person who tracks which parts have been filmed, how the filmed scenes deviated from the script; they also make continuity notes, creating a lined script. \(Source: IMDb\)' );
INSERT INTO libdb_roles_types VALUES ( '8RgQG7qTbWO7e4Bzkd79', 'Set Decorator',                  'A person who has total charge of decorating the set with all furnishings, drapery, interior plants, and anything seen on indoor or outdoor sets. The set decorator has authority over a leadman. See also set dresser. \(Source: IMDb\)' );
INSERT INTO libdb_roles_types VALUES ( '1H7tVsmrA1mbrxQWTKfA', 'Set Designer',                   'The person responsible for translating a production designer\'s vision of the movie\'s environment into a set which can be used for filming. The set designer reports to the art director. \(Source: IMDb\)' );
INSERT INTO libdb_roles_types VALUES ( 'pFJFOSGZacwq8n2PGoc2', 'Set Director',                   'The art director\'s assistant in designing and constructing sets. \(Source: IMDb\)' );
INSERT INTO libdb_roles_types VALUES ( 'NhsS4CtYP5JuMRmiLkV1', 'Set Dresser',                    'A person who physically decorates a set, placing elements such as curtains and paintings. \(Source: IMDb\)' );
INSERT INTO libdb_roles_types VALUES ( '5VdpYGhWgQxn6EUtZBmG', 'Sound Effects Editor',           'A sound editor who specialises in editing sound effects. \(Source: IMDb\)' );
INSERT INTO libdb_roles_types VALUES ( 'VULtTAj3E0hGEaX5adDW', 'Sound Re-Recording Mixer',       'The process of creating the soundtrack for a visual program, the sound re-recording mixer usually handles several processes during audio post-postproduction. Each different project may need some, or all of these processes in order to be complete. The processes are production dialog editing, ADR \(automated dialogue replacement\), sound effects editing and design, foley recording, and music composition and editing. \(Source: FilmSound.org\)' );
INSERT INTO libdb_roles_types VALUES ( 'tLdF2IBWgL3LlGrwDvKb', 'Special Effects',                'An artificial effect used to create an illusion in a movie. Refers to effects produced on the set, as opposed to those created in post-production \(visual effects\). \(Source: IMDb\)' );
INSERT INTO libdb_roles_types VALUES ( 'owGjmb2xePOL8VDomyNG', 'Special Effects Supervisor',     'The chief of a production\'s special effects crew and also known as a special effects coordinator, the supervisor is a specialist in miniatures, mechanical effects, pyrotechnics, matte painting, animation, model making, and special photograph. \(Source: LibDB and the FilmFrog archives\)' );
INSERT INTO libdb_roles_types VALUES ( '6jcSBcq5pey1pg3JO6HK', 'Steadicam Operator',             'A camera operator who operates a Steadicam. \(Source: IMDb\)' );
INSERT INTO libdb_roles_types VALUES ( 'APLUggb5HgSeunubsNdu', 'Stereo Sound Consultant',        'These consultants provide technical and creative assistance to help dubbing studios, film laboratories, and cinemas use their sound technology \(such as Dolby, THX, Skywalker Sound, etc.\). In most cases, if a stereo sound consultant is credited, the company he represents will be created as well. \(Source: LibDB and Dolby\)' );
INSERT INTO libdb_roles_types VALUES ( 'QqxnkE1Q3nr7Sqse5frt', 'Still Photographer',             'A person who photographs the action \(often alongside the camera\) to be used in publicizing the movie. (Source: IMDb)' );
INSERT INTO libdb_roles_types VALUES ( 'NYzqApY1E4uIeKHBoVRa', 'Stunt Coordinator',              'A person who arranges and plans stunts. (Source: IMDb)' );
INSERT INTO libdb_roles_types VALUES ( 'ZrYdGUdw5VqkonTJ7fBg', 'Stunt Double',                   'A stunt performer who specifically takes the part of another actor for a stunt. Stunt doubles rarely \(if ever\) speak, are typically chosen to resemble the actor that they are replacing as much as possible. \(Source: IMDb\)' );
INSERT INTO libdb_roles_types VALUES ( 'aSHzIj4L8ReYdywhAZaF', 'Supervising Sound Editor',       'A chief sound editor. \(Source: IMDb\)' );
INSERT INTO libdb_roles_types VALUES ( 'cWMgU2R2efLOpbXBFvpo', 'Title Design',                   'The manner in which title of a movie is displayed on screen is widely considered an art form. \(Source: IMDb\)' );
INSERT INTO libdb_roles_types VALUES ( 'Itak3WEpVXVTnk7z6pKD', 'Titles',                         'The persons or company behind a film\'s opening credit sequence. \(Source: LibDB\)' );
INSERT INTO libdb_roles_types VALUES ( 'M9caBRooc6N5W2WVriGD', 'Underwater Camera Operator',     'The person who operates an underwater camera to the specifications dictated by the director of photography. \(Source: IMDb, LibDB\)' );
INSERT INTO libdb_roles_types VALUES ( 'ev6sYSM2rDxNggrPWkMx', 'Unit Production Manager',        'An executive who is responsible to a senior producer for the administration of a particular movie. Unit Production Managers only work on one film at a time. See also production manager, line producer. \(Source: IMDb\)' );
INSERT INTO libdb_roles_types VALUES ( 'U9mEbuTXVd9pxzaVHJBG', 'Unit Publicist',                 'Member of the publicity department who works on location during the production of a movie. Duties includes working with the residents of the location where the film is being made, as well as setting up press visits and electronic press kit interviews. In addition, the unit publicist assembles the biographical materials and notes about the making of the movie that are later turned into the movie press kit. Unit publicists are itinerant -- they move from production to production and are on the production payroll. They report to the filmmakers and, if the film has a releasing studio, they also report to the publicity directors. Once principal photography is over, the unit publicist moves on to another job. \(Source: IMDb\)' );
INSERT INTO libdb_roles_types VALUES ( 'te7oQ8mAio1Y1cgnqCE7', 'Video Playback Engineer',        'The playback engineer or operator works a video camera mounted in parallel with the film camera. The footage of the video should be representative of what will print to film, and this approximation allows directors to get a feel for a shot without having to wait for dailies. Seen as unreliable in the early years, it helped directors establish blocking for actors who needed it, kept boom mic operators out of shots, etc. \(Source: LibDB\)' );
INSERT INTO libdb_roles_types VALUES ( 'vaEQzt5U2TbjFDdYWmrO', 'Visual Effects',                 'Alterations to a film\'s images during post-production. Contrast with special effects. \(Source: IMDb\)' );
INSERT INTO libdb_roles_types VALUES ( 'iCm9CsmGi1PbfPLmjGbr', 'Writer',                         'A general term for someone who creates a written work, be it a novel, script, screenplay, or teleplay. \(Source: IMDb\)' );

-- ----------------------------------------------------------------------- --

CREATE TABLE libdb_variants ( id CHAR(20) NOT NULL, referer_table VARCHAR(50) NOT NULL, referer_id CHAR(20) NOT NULL, title TEXT, name VARCHAR(255), given_name VARCHAR(255), family_name VARCHAR(255), language VARCHAR(5) );
